@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.16 1999/08/04 21:31:03 bazsi Exp $ */
+ * $Id: io.c,v 1.17 1999/08/31 20:57:35 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -1226,7 +1226,7 @@ struct io_fd *io_write(struct io_fd *f,
 	return f;
 }
 
-void io_callout(struct io_backend *backend, time_t timeout, struct callback *callout)
+struct callout *io_callout(struct io_backend *backend, time_t timeout, struct callback *callout)
 {
 	struct callout *co;
 
@@ -1234,8 +1234,15 @@ void io_callout(struct io_backend *backend, time_t timeout, struct callback *cal
 	co->when = time(NULL) + timeout;
 	co->callout = callout;
 	ol_queue_add_tail(&backend->callouts, &co->header);
+	return co;
 }
 
+void io_callout_set_timeout(struct callout *co, time_t timeout)
+{
+	co->when = time(NULL) + timeout;
+}
+
+
 void kill_fd(struct nonblocking_fd *fd)
 {
 	fd->super.alive = 0;
