@@ -196,6 +196,8 @@
        (callouts special-struct "struct ol_queue" do_mark_callouts do_free_callouts)))
 */
 
+struct callout;
+
 void init_backend(struct io_backend *b);
 
 int io_iter(struct io_backend *b);
@@ -265,8 +267,9 @@ struct io_fd *io_write(struct io_fd *fd,
 		       struct abstract_buffer *buffer,
 		       struct close_callback *close_callback);
 
+struct callout *io_callout(struct io_backend *backend, time_t timeout, struct callback *callout);
 
-void io_callout(struct io_backend *backend, time_t timeout, struct callback *callout);
+void io_callout_set_timeout(struct callout *co, time_t timeout);
 
 #define closekill_fd(fd, reason) close_fd(fd, reason), kill_fd(fd)
 
